(cli)=

(commands)=

# Commands

```{toctree}
:caption: General commands
:maxdepth: 1

load
shell
ls
```

```{toctree}
:caption: Configuration
:maxdepth: 1

edit
import
convert
freeze

```

```{toctree}
:caption: Diagnostic
:maxdepth: 1

debug-info

```

```{toctree}
:caption: More
:maxdepth: 1

completion
```
